@@ -1,10 +1,11 @@
 //! This part of the library is designed for mathematics and physics - evaluating postfix-notation expressions, unions on customised sets or temperature conversion;Those features are among those implemented for LibRapid.
 mod ztheory; 
-mod fast_primes;
 pub mod general;
 pub mod constants;
-pub mod sets;
 pub mod vectors;
 pub mod postfix;
 pub mod unit_conversion;
 pub mod primes;
+pub mod sets;
+pub mod equations;
+pub mod complex;
